Over-sampling-based ensembles — imbalanced-ensemble 0.1.0 documentation

# Over-sampling-based ensembles

The `imbalanced_ensemble.ensemble.over_sampling` submodule contains a set of over-sampling-based ensemble imbalanced learning methods.

`OverBoostClassifier`(**kwargs) | Random over-sampling integrated in the learning of AdaBoost.
`SMOTEBoostClassifier`(**kwargs) | SMOTE over-sampling integrated in the learning of AdaBoost.
`KmeansSMOTEBoostClassifier`(**kwargs) | Kmeans-SMOTE over-sampling integrated in the learning of AdaBoost.
`OverBaggingClassifier`(**kwargs) | A Bagging classifier with intergrated random over-sampling.
`SMOTEBaggingClassifier`(**kwargs) | A Bagging classifier with intergrated SMOTE over-sampling.